pub struct FrontmatterBlock {
pub line_range: FrontmatterLineRange,
pub json_pointer: Option<String>,
}Expand description
The frontmatter block a diagnostic is about, and the value within it.
Fields
line_range: FrontmatterLineRangeOne-based inclusive line range of the complete frontmatter block.
json_pointer: Option<String>JSON Pointer of a value rejected by JSON Schema, when applicable.