Heading

Struct Heading 

pub struct Heading {
    pub level: HeaderLevel,
    pub text: String,
    pub diagnostic_text: String,
    pub source_text: String,
    pub location: HeadingLocation,
    pub suppressions: Suppressions,
}
A normalized and positioned Markdown heading.

Fields

level: HeaderLevel

The ATX level, or the equivalent level of a Setext heading.

text: String

Text used by matchers, normalized according to MarkdownOptions.

diagnostic_text: String

Visible, case-preserving text suitable for diagnostics.

Unlike Self::text, this always has inline markup stripped.

source_text: String

Header content as spelled in the source after removing block markers.

Backslash escapes, entity references, and inline markup remain intact.

location: HeadingLocation

The source extent and one-based anchor position of the heading.

suppressions: Suppressions

Diagnostic ids disabled by a directive on the immediately prior line.