pub struct MarkdownOptions {
pub strip_inline_markup: bool,
}Expand description
Options that affect conversion of a Markdown heading into matcher text.
Fields
strip_inline_markup: boolReduce inline markup to visible text while retaining the unmodified
source spelling separately on Heading::source_text.