pub struct RegexPattern(/* private fields */);Expand description
The validated body of a regular-expression matcher, without / delimiters.
Construction is restricted to the schema loader so callers cannot create a semantic schema containing an invalid regular expression.
Implementations