pub struct RelatedLocation {
pub range: SourceRange,
pub message: String,
}Expand description
A secondary source range attached to a schema error.
Fields
range: SourceRangeSecondary source range relevant to the error.
message: StringExplanation of how the secondary location relates to the error.