pub struct RuleRef {
pub anchor: RefAnchor,
pub path: NonEmpty<RuleId>,
}Expand description
A normalized reference to a rule path.
Fields
anchor: RefAnchorThe scope from which the first path segment is resolved.
path: NonEmpty<RuleId>One or more rule identifiers forming the path to the target.