pub struct SchemaLocations {
pub document: SourceRange,
pub nodes: BTreeMap<SchemaNode, SourceRange>,
}Expand description
Side-car locations for nodes in a successfully built Schema.
Node addresses follow the structure of the normalized schema rather than using rule ids, which are optional and only locally unique.
Fields
document: SourceRangeThe range covering the complete primary Outlint schema document.
nodes: BTreeMap<SchemaNode, SourceRange>Source ranges for semantic nodes needed by validation diagnostics.