pub struct SchemaSource {
pub label: Option<SourceLabel>,
pub text: Arc<str>,
}Expand description
The available source text and optional display name of a schema document.
Fields
label: Option<SourceLabel>A path, URI, or caller-provided label used when presenting diagnostics.
text: Arc<str>The complete original text, or empty when reading this source failed.