SchemaSources

Struct SchemaSources 

pub struct SchemaSources {
    pub primary: SourceId,
    pub documents: BTreeMap<SourceId, SchemaSource>,
}
All source documents participating in one schema load.

SourceId values are local to this collection. Keeping source identity in the parser result, instead of in semantic schema nodes, preserves position-independent equality for Schema.

Fields

primary: SourceId

The Outlint schema document requested by the caller.

documents: BTreeMap<SourceId, SchemaSource>

Source text keyed by the ids used in locations and errors.