#[repr(transparent)]pub struct ScopePath(pub Vec<RuleIndex>);Expand description
A path to a rule-owned child scope.
Each index selects a rule whose child scope contains the next index. For an
outline: schema, the empty path denotes Schema::outline. For a
title: + sections: sugar schema, it denotes the synthesized title
rule’s child scope — the source’s top-level sections: list. This preserves
the public addressing of the source form after normalization.
Tuple Fields
0: Vec<RuleIndex>Trait Implementations
impl Eq for ScopePath
Sourceimpl Ord for ScopePath
impl Ord for ScopePath
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for ScopePath
impl PartialOrd for ScopePath
impl StructuralPartialEq for ScopePath