pub struct HeadingLocation {
pub range: TextRange,
pub line_range: TextRange,
pub line: u64,
pub column: u64,
}Expand description
Source position of a Markdown heading.
Fields
range: TextRangeHalf-open byte range of the complete ATX or Setext heading block.
line_range: TextRangeHalf-open byte range of the first source line used for anchoring.
line: u64One-based source line containing the heading text or ATX marker.
column: u64One-based byte column of the heading text or ATX marker.
Markdown indentation is ASCII, so this is also the character column.